@@ -1,6 +1,7 @@
-import asyncio
-from concurrent.futures import Executor
-
+from __future__ import annotations
+from typing import TYPE_CHECKING
+if TYPE_CHECKING:
+    from panoptic.core.project.project import Project
 
 class Task:
     """
@@ -8,22 +9,22 @@ class Task:
     To use the task class outside the TaskQueue you need to set_executor manually
     """
     def __init__(self, priority=False):
-        self._executor: Executor | None = None
+        self._project: Project | None = None
         self.has_priority = priority
         self.name = type(self).__name__
         self.key = type(self).__name__
 
-    def set_executor(self, executor: Executor):
-        self._executor = executor
+    def set_project(self, project: Project):
+        self._project = project
 
     def get_id(self):
         return self.key
 
-    async def _async(self, function, *args):
+    async def run_async(self, function, *args):
         """
         Make function awaitable and execute in Executor
         """
-        return await asyncio.wrap_future(self._executor.submit(function, *args))
+        return await self._project.run_async(function, *args)
 
     async def run(self):
         raise NotImplementedError()
